xema v0.11.0 Xema.Ref View Source
This module contains a struct and functions to represent and handle references.
Link to this section Summary
Functions
Returns the schema and the root for the given ref and xema.
Creates a new reference from the given pointer.
Creates a new reference from the given pointer and uri.
Validates the given value with the referenced schema.
Link to this section Types
A reference contains a pointer and an optional uri.
Link to this section Functions
Returns the schema and the root for the given ref and xema.
Returns the reference key for a Ref or an URI.
Creates a new reference from the given pointer.
Creates a new reference from the given pointer and uri.
Link to this function
validate(ref, value, opts)
View Sourcevalidate(Xema.Ref.t(), any(), keyword()) :: :ok | {:error, map()}
Validates the given value with the referenced schema.