Xema.SchemaValidator
(xema v0.17.7)
A validator for the schema input.
Summary
Functions
Returns :ok if the data valid against the xema schema.
Functions
@spec validate!(any()) :: :ok
Returns :ok if the data valid against the xema schema.