xema v0.9.2 Xema.Ref View Source
This module contains a struct and functions to represent and handle references.
Link to this section Summary
Functions
Returns the schema and the root for the given ref and xema.
Creates a new reference from the given pointer.
Creates a new reference from the given pointer and uri.
Validates the given value with the referenced schema.
Link to this section Types
A reference contains a pointer and an optional uri.
Link to this section Functions
Link to this function
fetch!(ref, master, root) View Source
Returns the schema and the root for the given ref and xema.
Link to this function
fragment(ref) View Source
Link to this function
key(uri)
key(uri)
key(ref :: Xema.Ref.t() | URI.t()) :: String.t()
key(ref :: Xema.Ref.t() | URI.t()) :: String.t()
Returns the reference key for a Ref or an URI.
Link to this function
new(pointer)
new(pointer)
new(String.t()) :: Xema.Ref.t()
new(String.t()) :: Xema.Ref.t()
Creates a new reference from the given pointer.
Link to this function
new(pointer, uri)
new(pointer, uri)
new(String.t(), URI.t() | nil) :: Xema.Ref.t()
new(String.t(), URI.t() | nil) :: Xema.Ref.t()
Creates a new reference from the given pointer and uri.
Link to this function
validate(ref, value, opts)
validate(ref, value, opts)
validate(Xema.Ref.t(), any(), keyword()) :: :ok | {:error, map()}
validate(Xema.Ref.t(), any(), keyword()) :: :ok | {:error, map()}
Validates the given value with the referenced schema.